[asterisk-commits] oej: trunk r56665 - in /trunk: apps/ channels/ include/asterisk/ main/ pbx/ res/

asterisk-commits at lists.digium.com asterisk-commits at lists.digium.com
Sat Feb 24 13:29:42 MST 2007


Author: oej
Date: Sat Feb 24 14:29:41 2007
New Revision: 56665

URL: http://svn.digium.com/view/asterisk?view=rev&rev=56665
Log:
Doxygen additions, corrections

Modified:
    trunk/apps/app_amd.c
    trunk/apps/app_meetme.c
    trunk/channels/chan_h323.c
    trunk/include/asterisk/ael_structs.h
    trunk/include/asterisk/config.h
    trunk/include/asterisk/doxyref.h
    trunk/include/asterisk/http.h
    trunk/include/asterisk/jingle.h
    trunk/include/asterisk/utils.h
    trunk/include/asterisk/zapata.h
    trunk/main/channel.c
    trunk/main/config.c
    trunk/main/rtp.c
    trunk/pbx/pbx_ael.c
    trunk/res/res_limit.c

Modified: trunk/apps/app_amd.c
URL: http://svn.digium.com/view/asterisk/trunk/apps/app_amd.c?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/apps/app_amd.c (original)
+++ trunk/apps/app_amd.c Sat Feb 24 14:29:41 2007
@@ -18,6 +18,14 @@
  * A license has been granted to Digium (via disclaimer) for the use of
  * this code.
  */
+
+/*! \file
+ *
+ * \brief Answering machine detection
+ *
+ * \author Claude Klimos (claude.klimos at aheeva.com)
+ */
+
 
 #include "asterisk.h"
  

Modified: trunk/apps/app_meetme.c
URL: http://svn.digium.com/view/asterisk/trunk/apps/app_meetme.c?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/apps/app_meetme.c (original)
+++ trunk/apps/app_meetme.c Sat Feb 24 14:29:41 2007
@@ -334,6 +334,7 @@
 	int actual;                             /*!< Actual volume adjustment (for channels that can't adjust) */
 };
 
+/*! \brief The MeetMe User object */
 struct ast_conf_user {
 	int user_no;                            /*!< User Number */
 	int userflags;                          /*!< Flags as set in the conference */

Modified: trunk/channels/chan_h323.c
URL: http://svn.digium.com/view/asterisk/trunk/channels/chan_h323.c?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/include/asterisk/ael_structs.h (original)
+++ trunk/include/asterisk/ael_structs.h Sat Feb 24 14:29:41 2007
@@ -1,3 +1,27 @@
+/*
+ * Asterisk -- An open source telephony toolkit.
+ *
+ * Copyright (C) 1999 - 2007, Digium, Inc.
+ *
+ * Mark Spencer <markster at digium.com>
+ *
+ * See http://www.asterisk.org for more information about
+ * the Asterisk project. Please do not directly contact
+ * any of the maintainers of this project for assistance;
+ * the project provides a web site, mailing lists and IRC
+ * channels for your use.
+ *
+ * This program is free software, distributed under the terms of
+ * the GNU General Public License Version 2. See the LICENSE file
+ * at the top of the source tree.
+ */
+
+/*! \file
+ * \brief Structures for AEL - the Asterisk extension language
+ *
+ * \ref pbx_ael.c
+ */
+
 #ifndef _ASTERISK_AEL_STRUCTS_H
 #define _ASTERISK_AEL_STRUCTS_H
 
@@ -22,8 +46,7 @@
 #  endif
 
 
-typedef enum 
-{
+typedef enum {
 	PV_WORD, /* an ident, string, name, label, etc. A user-supplied string. */ /* 0 */
 	PV_MACRO,             /* 1 */
 	PV_CONTEXT,           /* 2 */

Modified: trunk/include/asterisk/config.h
URL: http://svn.digium.com/view/asterisk/trunk/include/asterisk/config.h?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/include/asterisk/config.h (original)
+++ trunk/include/asterisk/config.h Sat Feb 24 14:29:41 2007
@@ -33,6 +33,8 @@
 
 struct ast_category;
 
+/*! \brief Structure for variables, used for configurations and for channel variables 
+*/
 struct ast_variable {
 	char *name;
 	char *value;
@@ -50,6 +52,7 @@
 typedef struct ast_config *realtime_multi_get(const char *database, const char *table, va_list ap);
 typedef int realtime_update(const char *database, const char *table, const char *keyfield, const char *entity, va_list ap);
 
+/*! \brief Configuration engine structure, used to define realtime drivers */
 struct ast_config_engine {
 	char *name;
 	config_load_func *load_func;

Modified: trunk/include/asterisk/doxyref.h
URL: http://svn.digium.com/view/asterisk/trunk/include/asterisk/doxyref.h?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/include/asterisk/doxyref.h (original)
+++ trunk/include/asterisk/doxyref.h Sat Feb 24 14:29:41 2007
@@ -16,7 +16,7 @@
  * at the top of the source tree.
  */
 
-/* \file This file generates Doxygen pages from files in the /doc
+/*! \file This file generates Doxygen pages from files in the /doc
  directory of the Asterisk source code tree 
  */
 

Modified: trunk/include/asterisk/http.h
URL: http://svn.digium.com/view/asterisk/trunk/include/asterisk/http.h?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/include/asterisk/http.h (original)
+++ trunk/include/asterisk/http.h Sat Feb 24 14:29:41 2007
@@ -147,6 +147,7 @@
 */
 typedef struct ast_str *(*ast_http_callback)(struct sockaddr_in *requestor, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength);
 
+/*! \brief Definition of a URI reachable in the embedded HTTP server */
 struct ast_http_uri {
 	AST_LIST_ENTRY(ast_http_uri) entry;
 	const char *description;

Modified: trunk/include/asterisk/jingle.h
URL: http://svn.digium.com/view/asterisk/trunk/include/asterisk/jingle.h?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/include/asterisk/jingle.h (original)
+++ trunk/include/asterisk/jingle.h Sat Feb 24 14:29:41 2007
@@ -15,6 +15,15 @@
  * the GNU General Public License Version 2. See the LICENSE file
  * at the top of the source tree.
  */
+
+/*! \file
+ * \brief Jingle definitions for chan_jingle
+ *
+ * \ref chan_jingle.c
+ *
+ * \author Matt O'Gorman <mogorman at digium.com>
+ */
+
 
 #ifndef _ASTERISK_JINGLE_H
 #define _ASTERISK_JINGLE_H

Modified: trunk/include/asterisk/utils.h
URL: http://svn.digium.com/view/asterisk/trunk/include/asterisk/utils.h?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/include/asterisk/utils.h (original)
+++ trunk/include/asterisk/utils.h Sat Feb 24 14:29:41 2007
@@ -39,8 +39,8 @@
 #include "asterisk/logger.h"
 #include "asterisk/compiler.h"
 
-/*! \note
- \verbatim
+/*! 
+\note \verbatim
    Note:
    It is very important to use only unsigned variables to hold
    bit flags, as otherwise you can fall prey to the compiler's
@@ -141,6 +141,8 @@
 
 #define AST_FLAGS_ALL UINT_MAX
 
+/*! \brief Structure used to handle boolean flags 
+*/
 struct ast_flags {
 	unsigned int flags;
 };
@@ -150,22 +152,21 @@
 	char buf[1024];
 };
 
+/*! \brief Thread-safe gethostbyname function to use in Asterisk */
 struct hostent *ast_gethostbyname(const char *host, struct ast_hostent *hp);
 
-/* ast_md5_hash 
-	\brief Produces MD5 hash based on input string */
+/*!  \brief Produces MD5 hash based on input string */
 void ast_md5_hash(char *output, char *input);
-/* ast_sha1_hash
-	\brief Produces SHA1 hash based on input string */
+/*! \brief Produces SHA1 hash based on input string */
 void ast_sha1_hash(char *output, char *input);
 
 int ast_base64encode_full(char *dst, const unsigned char *src, int srclen, int max, int linebreaks);
 int ast_base64encode(char *dst, const unsigned char *src, int srclen, int max);
 int ast_base64decode(unsigned char *dst, const char *src, int max);
 
-/*! ast_uri_encode
-	\brief Turn text string to URI-encoded %XX version 
- 	At this point, we're converting from ISO-8859-x (8-bit), not UTF8
+/*!  \brief Turn text string to URI-encoded %XX version 
+
+\note 	At this point, we're converting from ISO-8859-x (8-bit), not UTF8
 	as in the SIP protocol spec 
 	If doreserved == 1 we will convert reserved characters also.
 	RFC 2396, section 2.4
@@ -238,7 +239,7 @@
 int ast_utils_init(void);
 int ast_wait_for_input(int fd, int ms);
 
-/*! ast_carefulwrite
+/*!
 	\brief Try to write string, but wait no more than ms milliseconds
 	before timing out.
 
@@ -249,7 +250,7 @@
 */
 int ast_carefulwrite(int fd, char *s, int len, int timeoutms);
 
-/*! Compares the source address and port of two sockaddr_in */
+/*! \brief Compares the source address and port of two sockaddr_in */
 static force_inline int inaddrcmp(const struct sockaddr_in *sin1, const struct sockaddr_in *sin2)
 {
 	return ((sin1->sin_addr.s_addr != sin2->sin_addr.s_addr) 

Modified: trunk/include/asterisk/zapata.h
URL: http://svn.digium.com/view/asterisk/trunk/include/asterisk/zapata.h?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/include/asterisk/zapata.h (original)
+++ trunk/include/asterisk/zapata.h Sat Feb 24 14:29:41 2007
@@ -16,6 +16,11 @@
  * Sometimes one really wonders why we need a copyright
  * for less than ten lines of preprocessor directives...
  */
+
+/*! \file
+ * \brief Stub to find zaptel headers
+ */
+
 
 /*
  * Stub to find the zaptel headers. The configure script will

Modified: trunk/main/channel.c
URL: http://svn.digium.com/view/asterisk/trunk/main/channel.c?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/main/channel.c (original)
+++ trunk/main/channel.c Sat Feb 24 14:29:41 2007
@@ -72,12 +72,15 @@
 	struct ast_trans_pvt *path;
 };
 
+/*! \brief List of SPY structures 
+*/
 struct ast_channel_spy_list {
 	struct channel_spy_trans read_translator;
 	struct channel_spy_trans write_translator;
 	AST_LIST_HEAD_NOLOCK(, ast_channel_spy) list;
 };
 
+/*! \brief Definition of the Whisper buffer */
 struct ast_channel_whisper_buffer {
 	ast_mutex_t lock;
 	struct ast_slinfactory sf;
@@ -88,10 +91,10 @@
 /* uncomment if you have problems with 'monitoring' synchronized files */
 #if 0
 #define MONITOR_CONSTANT_DELAY
-#define MONITOR_DELAY	150 * 8		/* 150 ms of MONITORING DELAY */
+#define MONITOR_DELAY	150 * 8		/*!< 150 ms of MONITORING DELAY */
 #endif
 
-/*! Prevent new channel allocation if shutting down. */
+/*! \brief Prevent new channel allocation if shutting down. */
 static int shutting_down;
 
 static int uniqueint;
@@ -101,22 +104,25 @@
 AST_THREADSTORAGE(state2str_threadbuf);
 #define STATE2STR_BUFSIZE   32
 
-/*! 100ms */
-#define AST_DEFAULT_EMULATE_DTMF_DURATION 100
-
+#define AST_DEFAULT_EMULATE_DTMF_DURATION 100 /*!< 100ms */
+
+/*! \brief List of channel drivers */
 struct chanlist {
 	const struct ast_channel_tech *tech;
 	AST_LIST_ENTRY(chanlist) list;
 };
 
-/*! the list of registered channel types */
+/*! \brief the list of registered channel types */
 static AST_LIST_HEAD_NOLOCK_STATIC(backends, chanlist);
 
-/*! the list of channels we have. Note that the lock for this list is used for
+/*! \brief the list of channels we have. Note that the lock for this list is used for
     both the channels list and the backends list.  */
 static AST_LIST_HEAD_STATIC(channels, ast_channel);
 
-/*! map AST_CAUSE's to readable string representations */
+/*! \brief map AST_CAUSE's to readable string representations 
+ *
+ * \ref causes.h
+*/
 const struct ast_cause {
 	int cause;
 	const char *name;
@@ -184,6 +190,7 @@
 	return var;
 }
 
+/*! \brief Show channel types - CLI command */
 static int show_channeltypes(int fd, int argc, char *argv[])
 {
 #define FORMAT  "%-10.10s  %-40.40s %-12.12s %-12.12s %-12.12s\n"
@@ -211,6 +218,7 @@
 
 }
 
+/*! \brief Show details about a channel driver - CLI command */
 static int show_channeltype(int fd, int argc, char *argv[])
 {
 	struct chanlist *cl = NULL;
@@ -428,6 +436,7 @@
 	return 0;
 }
 
+/*! \brief Unregister channel driver */
 void ast_channel_unregister(const struct ast_channel_tech *tech)
 {
 	struct chanlist *chan;
@@ -451,6 +460,7 @@
 	AST_LIST_UNLOCK(&channels);
 }
 
+/*! \brief Get handle to channel driver based on name */
 const struct ast_channel_tech *ast_get_channel_tech(const char *name)
 {
 	struct chanlist *chanls;

Modified: trunk/main/config.c
URL: http://svn.digium.com/view/asterisk/trunk/main/config.c?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/main/config.c (original)
+++ trunk/main/config.c Sat Feb 24 14:29:41 2007
@@ -70,6 +70,7 @@
 static int  lline_buffer_size;
 
 
+/*! \brief Structure to keep comments for rewriting configuration files */
 struct ast_comment {
 	struct ast_comment *next;
 	char cmt[0];

Modified: trunk/main/rtp.c
URL: http://svn.digium.com/view/asterisk/trunk/main/rtp.c?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/main/rtp.c (original)
+++ trunk/main/rtp.c Sat Feb 24 14:29:41 2007
@@ -3277,10 +3277,6 @@
 	return res;
 }
 
-/*! \brief Bridge calls. If possible and allowed, initiate
-	re-invite so the peers exchange media directly outside 
-	of Asterisk. 
-*/
 /*! \page AstRTPbridge The Asterisk RTP bridge 
 	The RTP bridge is called from the channel drivers that are using the RTP
 	subsystem in Asterisk - like SIP, H.323 and Jingle/Google Talk.
@@ -3306,6 +3302,12 @@
 	- ast_rtp_bridge()
 	- ast_channel_early_bridge()
 	- ast_channel_bridge()
+	- rtp.c
+	- rtp.h
+*/
+/*! \brief Bridge calls. If possible and allowed, initiate
+	re-invite so the peers exchange media directly outside 
+	of Asterisk. 
 */
 enum ast_bridge_result ast_rtp_bridge(struct ast_channel *c0, struct ast_channel *c1, int flags, struct ast_frame **fo, struct ast_channel **rc, int timeoutms)
 {

Modified: trunk/pbx/pbx_ael.c
URL: http://svn.digium.com/view/asterisk/trunk/pbx/pbx_ael.c?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/pbx/pbx_ael.c (original)
+++ trunk/pbx/pbx_ael.c Sat Feb 24 14:29:41 2007
@@ -70,7 +70,7 @@
    development, this code can be properly re-instated 
 */
 
-/* null definitions for structs passed down the infrastructure */
+/*! \brief null definitions for structs passed down the infrastructure */
 struct argapp
 {
 	struct argapp *next;
@@ -151,7 +151,7 @@
 static void remove_spaces_before_equals(char *str);
 static void substitute_commas(char *str);
 
-/* I am adding this code to substitute commas with vertbars in the args to apps */
+/*! \brief I am adding this code to substitute commas with vertbars in the args to apps */
 static void substitute_commas(char *str)
 {
 	char *p = str;

Modified: trunk/res/res_limit.c
URL: http://svn.digium.com/view/asterisk/trunk/res/res_limit.c?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================
--- trunk/res/res_limit.c (original)
+++ trunk/res/res_limit.c Sat Feb 24 14:29:41 2007
@@ -10,6 +10,14 @@
  * This code is released by the author with no restrictions on usage.
  *
  */
+
+/*! \file
+ *
+ * \brief Resource limits
+ *
+ * \author Tilghman Lesher <res_limit_200607 at the-tilghman.com>
+ */
+
 
 #include "asterisk.h"
 



More information about the asterisk-commits mailing list
--- trunk/channels/chan_h323.c (original)
+++ trunk/channels/chan_h323.c Sat Feb 24 14:29:41 2007
@@ -120,10 +120,9 @@
 setpeercapabilities_cb on_setpeercapabilities;
 onhold_cb on_hold;
 
-/* global debug flag */
-int h323debug;
-
-/*! Global jitterbuffer configuration - by default, jb is disabled */
+int h323debug; /*!< global debug flag */
+
+/*! \brief Global jitterbuffer configuration - by default, jb is disabled */
 static struct ast_jb_conf default_jbconf =
 {
 	.flags = 0,
@@ -156,79 +155,81 @@
 
 static call_options_t global_options;
 
-/** Private structure of a OpenH323 channel */
+/*! \brief Private structure of a OpenH323 channel */
 struct oh323_pvt {
-	ast_mutex_t lock;					/* Channel private lock */
-	call_options_t options;				/* Options to be used during call setup */
-	int alreadygone;					/* Whether or not we've already been destroyed by our peer */
-	int needdestroy;					/* if we need to be destroyed */
-	call_details_t cd;					/* Call details */
-	struct ast_channel *owner;			/* Who owns us */
-	struct sockaddr_in sa;				/* Our peer */
-	struct sockaddr_in redirip;			/* Where our RTP should be going if not to us */
-	int nonCodecCapability;				/* non-audio capability */
-	int outgoing;						/* Outgoing or incoming call? */
-	char exten[AST_MAX_EXTENSION];		/* Requested extension */
-	char context[AST_MAX_CONTEXT];		/* Context where to start */
-	char accountcode[256];				/* Account code */
-	char rdnis[80];						/* Referring DNIS, if available */
-	int amaflags;						/* AMA Flags */
-	struct ast_rtp *rtp;				/* RTP Session */
-	struct ast_dsp *vad;				/* Used for in-band DTMF detection */
-	int nativeformats;					/* Codec formats supported by a channel */
-	int needhangup;						/* Send hangup when Asterisk is ready */
-	int hangupcause;					/* Hangup cause from OpenH323 layer */
-	int newstate;						/* Pending state change */
-	int newcontrol;						/* Pending control to send */
-	int newdigit;						/* Pending DTMF digit to send */
-	int newduration;					/* Pending DTMF digit duration to send */
-	int pref_codec;						/* Preferred codec */
-	int peercapability;					/* Capabilities learned from peer */
-	int jointcapability;				/* Common capabilities for local and remote side */
-	struct ast_codec_pref peer_prefs;	/* Preferenced list of codecs which remote side supports */
-	int dtmf_pt[2];						/* Payload code used for RFC2833/CISCO messages */
-	int curDTMF;						/* DTMF tone being generated to Asterisk side */
-	int DTMFsched;						/* Scheduler descriptor for DTMF */
-	int update_rtp_info;				/* Configuration of fd's array is pending */
-	int recvonly;						/* Peer isn't wish to receive our voice stream */
-	int txDtmfDigit;					/* DTMF digit being to send to H.323 side */
-	int noInbandDtmf;					/* Inband DTMF processing by DSP isn't available */
-	int connection_established;			/* Call got CONNECT message */
-	int got_progress;					/* Call got PROGRESS message, pass inband audio */
-	struct oh323_pvt *next;				/* Next channel in list */
+	ast_mutex_t lock;			/*!< Channel private lock */
+	call_options_t options;			/*!<!< Options to be used during call setup */
+	int alreadygone;			/*!< Whether or not we've already been destroyed by our peer */
+	int needdestroy;			/*!< if we need to be destroyed */
+	call_details_t cd;			/*!< Call details */
+	struct ast_channel *owner;		/*!< Who owns us */
+	struct sockaddr_in sa;			/*!< Our peer */
+	struct sockaddr_in redirip;		/*!< Where our RTP should be going if not to us */
+	int nonCodecCapability;			/*!< non-audio capability */
+	int outgoing;				/*!< Outgoing or incoming call? */
+	char exten[AST_MAX_EXTENSION];		/*!< Requested extension */
+	char context[AST_MAX_CONTEXT];		/*!< Context where to start */
+	char accountcode[256];			/*!< Account code */
+	char rdnis[80];				/*!< Referring DNIS, if available */
+	int amaflags;				/*!< AMA Flags */
+	struct ast_rtp *rtp;			/*!< RTP Session */
+	struct ast_dsp *vad;			/*!< Used for in-band DTMF detection */
+	int nativeformats;			/*!< Codec formats supported by a channel */
+	int needhangup;				/*!< Send hangup when Asterisk is ready */
+	int hangupcause;			/*!< Hangup cause from OpenH323 layer */
+	int newstate;				/*!< Pending state change */
+	int newcontrol;				/*!< Pending control to send */
+	int newdigit;				/*!< Pending DTMF digit to send */
+	int newduration;			/*!< Pending DTMF digit duration to send */
+	int pref_codec;				/*!< Preferred codec */
+	int peercapability;			/*!< Capabilities learned from peer */
+	int jointcapability;			/*!< Common capabilities for local and remote side */
+	struct ast_codec_pref peer_prefs;	/*!< Preferenced list of codecs which remote side supports */
+	int dtmf_pt[2];				/*!< Payload code used for RFC2833/CISCO messages */
+	int curDTMF;				/*!< DTMF tone being generated to Asterisk side */
+	int DTMFsched;				/*!< Scheduler descriptor for DTMF */
+	int update_rtp_info;			/*!< Configuration of fd's array is pending */
+	int recvonly;				/*!< Peer isn't wish to receive our voice stream */
+	int txDtmfDigit;			/*!< DTMF digit being to send to H.323 side */
+	int noInbandDtmf;			/*!< Inband DTMF processing by DSP isn't available */
+	int connection_established;		/*!< Call got CONNECT message */
+	int got_progress;			/*!< Call got PROGRESS message, pass inband audio */
+	struct oh323_pvt *next;			/*!< Next channel in list */
 } *iflist = NULL;
 
-static struct ast_user_list {
+/*! \brief H323 User list */
+static struct h323_user_list {
 	ASTOBJ_CONTAINER_COMPONENTS(struct oh323_user);
 } userl;
 
-static struct ast_peer_list {
+/*! \brief H323 peer list */
+static struct h323_peer_list {
 	ASTOBJ_CONTAINER_COMPONENTS(struct oh323_peer);
 } peerl;
 
-static struct ast_alias_list {
+/*! \brief H323 alias list */
+static struct h323_alias_list {
 	ASTOBJ_CONTAINER_COMPONENTS(struct oh323_alias);
 } aliasl;
 
-/** Asterisk RTP stuff */
+/* Asterisk RTP stuff */
 static struct sched_context *sched;
 static struct io_context *io;
 
-/** Protect the interface list (oh323_pvt) */
-AST_MUTEX_DEFINE_STATIC(iflock);
-
-/* Protect the monitoring thread, so only one process can kill or start it, and not
+AST_MUTEX_DEFINE_STATIC(iflock);	/*!< Protect the interface list (oh323_pvt) */
+
+/*! \brief  Protect the H.323 monitoring thread, so only one process can kill or start it, and not
    when it's doing something critical. */
 AST_MUTEX_DEFINE_STATIC(monlock);
 
-/* Protect the H.323 capabilities list, to avoid more than one channel to set the capabilities simultaneaously in the h323 stack. */
+/*! \brief Protect the H.323 capabilities list, to avoid more than one channel to set the capabilities simultaneaously in the h323 stack. */
 AST_MUTEX_DEFINE_STATIC(caplock);
 
-/* Protect the reload process */
+/*! \brief Protect the reload process */
 AST_MUTEX_DEFINE_STATIC(h323_reload_lock);
 static int h323_reloading = 0;
 
-/* This is the thread for the monitor which checks for input on the channels
+/*! \brief This is the thread for the monitor which checks for input on the channels
    which are not currently in use. */
 static pthread_t monitor_thread = AST_PTHREADT_NULL;
 static int restart_monitor(void);
@@ -336,7 +337,7 @@
 	return 0;
 }
 
-/* Channel and private structures should be already locked */
+/*! \brief Channel and private structures should be already locked */
 static void __oh323_update_info(struct ast_channel *c, struct oh323_pvt *pvt)
 {
 	if (c->nativeformats != pvt->nativeformats) {
@@ -402,7 +403,7 @@
 	}
 }
 
-/* Only channel structure should be locked */
+/*! \brief Only channel structure should be locked */
 static void oh323_update_info(struct ast_channel *c)
 {
 	struct oh323_pvt *pvt = c->tech_pvt;
@@ -546,7 +547,7 @@
 	return 0;
 }
 
-/**
+/*! \brief
  * Send (play) the specified digit to the channel.
  *
  */
@@ -584,7 +585,7 @@
 	return 0;
 }
 
-/**
+/*! \brief
  * Make a call over the specified channel to the specified
  * destination.
  * Returns -1 on error, 0 on success.
@@ -757,9 +758,9 @@
 	return 0;
 }
 
+/*! \brief Retrieve audio/etc from channel. Assumes pvt->lock is already held. */
 static struct ast_frame *oh323_rtp_read(struct oh323_pvt *pvt)
 {
-	/* Retrieve audio/etc from channel. Assumes pvt->lock is already held. */
 	struct ast_frame *f;
 
 	/* Only apply it for the first packet, we just need the correct ip/port */
@@ -1004,7 +1005,7 @@
 	return 0;
 }
 
-/* Private structure should be locked on a call */
+/*! \brief Private structure should be locked on a call */
 static struct ast_channel *__oh323_new(struct oh323_pvt *pvt, int state, const char *host)
 {
 	struct ast_channel *ch;
@@ -1811,7 +1812,7 @@
 	return tmpc;
 }
 
-/** Find a call by alias */
+/*! \brief Find a call by alias */
 static struct oh323_alias *find_alias(const char *source_aliases, int realtime)
 {
 	struct oh323_alias *a;
@@ -1824,7 +1825,7 @@
 	return a;
 }
 
-/**
+/*! \brief
   * Callback for sending digits from H.323 up to asterisk
   *
   */
@@ -1895,10 +1896,10 @@
 	return res;
 }
 
-/**
+/*! \brief
   * Callback function used to inform the H.323 stack of the local rtp ip/port details
   *
-  * Returns the local RTP information
+  * \return Returns the local RTP information
   */
 static struct rtp_info *external_rtp_create(unsigned call_reference, const char * token)
 {
@@ -1936,7 +1937,7 @@
 	return info;
 }
 
-/**
+/*! \brief
  * Definition taken from rtp.c for rtpPayloadType because we need it here.
  */
 struct rtpPayloadType {
@@ -1944,7 +1945,7 @@
 	int code;
 };
 
-/**
+/*! \brief
   * Call-back function passing remote ip/port information from H.323 to asterisk
   *
   * Returns nothing
@@ -2054,7 +2055,7 @@
 	return;
 }
 
-/**
+/*! \brief
   *	Call-back function to signal asterisk that the channel has been answered
   * Returns nothing
   */
@@ -2108,7 +2109,7 @@
 	return 0;
 }
 
-/**
+/*! \brief
  *  Call-back function for incoming calls
  *
  *  Returns 1 on success
@@ -2228,7 +2229,7 @@
 	return &pvt->options;
 }
 
-/**
+/*! \brief
  * Call-back function to start PBX when OpenH323 ready to serve incoming call
  *
  * Returns 1 on success
@@ -2307,7 +2308,7 @@
 	return 1;
 }
 
-/**
+/*! \brief
  * Call-back function to establish an outgoing H.323 call
  *
  * Returns 1 on success
@@ -2320,7 +2321,7 @@
 	return 1;
 }
 
-/**
+/*! \brief
   *  Call-back function to signal asterisk that the channel is ringing
   *  Returns nothing
   */
@@ -2346,7 +2347,7 @@
 	return;
 }
 
-/**
+/*! \brief
   * Call-back function to cleanup communication
   * Returns nothing,
   */

Modified: trunk/include/asterisk/ael_structs.h
URL: http://svn.digium.com/view/asterisk/trunk/include/asterisk/ael_structs.h?view=diff&rev=56665&r1=56664&r2=56665
==============================================================================